@@ -614,9 +614,13 @@ module Loofah
                                           "collapse",
                                           "dashed",
                                           "dotted",
+                                          "double",
                                           "fuchsia",
                                           "gray",
                                           "green",
+                                          "groove",
+                                          "hidden",
+                                          "inset",
                                           "italic",
                                           "left",
                                           "lime",
@@ -627,9 +631,11 @@ module Loofah
                                           "normal",
                                           "nowrap",
                                           "olive",
+                                          "outset",
                                           "pointer",
                                           "purple",
                                           "red",
+                                          "ridge",
                                           "right",
                                           "silver",
                                           "solid",
